# Arch Linux Finalization

By default Arch Linux has very little software installed and even less configuration complete.

The following commands will finalize the fundamental Arch Linux setup and perform some mild tuning.

``` sh

# login as root with password root

# Initialize pacman
pacman-key --init
pacman-key --populate archlinuxarm

# Update system to latest software
pacman -Syy
pacman -Su
systemctl reboot

# Remove arch linux on arm default user
userdel alarm

# Set root password
passwd

# Turn on colorized pacman output
sed -i 's/#Color/Color/' /etc/pacman.conf # Add color to pacman

# Install fundamental tools
pacman -S openssh tmux nano vim htop iotop nload python python-pip wget curl git bash-completion p7zip exfat-utils man-db man-pages btrfs-progs sudo

# Tweak sshd to allow root login
sed -i 's/#PermitRootLogin prohibit-password/PermitRootLogin yes/g' /etc/ssh/sshd_config
systemctl enable --now sshd
systemctl restart sshd

# Finalize localiztation settings
ln -sf /usr/share/zoneinfo/UTC /etc/localtime
timedatectl set-local-rtc 0
timedatectl set-ntp true
echo LANG=en_US.UTF-8 > /etc/locale.conf
sed -i "s/#en_US.UTF-8/en_US.UTF-8/" /etc/locale.gen
locale-gen

# Finalize basic network config
nano -w /etc/hostname
nano -w /etc/hosts

# Turn off kernel audit logging
nano -w /boot/cmdline.txt
    add audit=0 at end of cmdline

# Reboot system for all changes to take effect
systemctl reboot

```